<?php

/**
 * @file
 * Contains Drupal\itchio_field\Plugin\Field\FieldType\ItchioItem.
 */

namespace Drupal\itchio_field\Plugin\Field\FieldType;

use Drupal\Core\Field\FieldItemBase;
use Drupal\Core\Field\FieldStorageDefinitionInterface;
use Drupal\Core\TypedData\DataDefinition;

/**
 * Plugin implementation of the 'itchio_field_itchio' field type.
 *
 * @FieldType(
 *   id = "itchio_field_itchio",
 *   label = @Translation("Itchio Field"),
 *   module = "itchio_field",
 *   description = @Translation("A field for an itch project number"),
 *   default_widget = "itchio_iframe",
 *   default_formatter = "itchio_formatter"
 * )
 */
class ItchioItem extends FieldItemBase {
  /**
   * {@inheritdoc}
   */
  public static function schema(FieldStorageDefinitionInterface $field_definition) {
    return array(
      'columns' => array(
        'value' => array(
          'type' => 'int',
          'size' => 'normal',
          'unsigned' => TRUE,
          'not null' => FALSE,
        ),
      ),
    );
  }

  /**
   * {@inheritdoc}
   */
  public function isEmpty() {
    $value = $this->get('value')->getValue();
    return $value === NULL || $value === '';
  }

  /**
   * {@inheritdoc}
   */
  public static function propertyDefinitions(FieldStorageDefinitionInterface $field_definition) {
    $properties['value'] = DataDefinition::create('string')
      ->setLabel(t('Itch project number'));

    return $properties;
  }

}
