<?php

/**
 * @file
 * Contains \Drupal\itchio_field\Plugin\Field\FieldWidget\ItchioIframeWidget.
 */

namespace Drupal\itchio_field\Plugin\Field\FieldWidget;

use Drupal\Core\Field\FieldItemListInterface;
use Drupal\Core\Field\WidgetBase;
use Drupal\Core\Form\FormStateInterface;

/**
 * Plugin implementation of the 'itchio_iframe' widget.
 *
 * @FieldWidget(
 *   id = "itchio_iframe",
 *   module = "itchio_field",
 *   label = @Translation("Itch.io iframe"),
 *   field_types = {
 *     "itchio_field_itchio"
 *   }
 * )
 */
class ItchioIframeWidget extends WidgetBase {

  /**
   * {@inheritdoc}
   */
  public function formElement(FieldItemListInterface $items, $delta, array $element, array &$form, FormStateInterface $form_state) {
    $value = isset($items[$delta]->value) ? $items[$delta]->value : '';
    $element += array(
      '#type' => 'textfield',
      '#default_value' => $value,
      '#size' => 20,
      '#maxlength' => 20,
      '#title' => t('Itchio Project Number'),
      '#description' => t('Your game\'s project number on Itch.io. This is the last value of the url on your game\'s edit page - i.e. http://itch.io/game/edit/XXXXX'),
      '#element_validate' => array(
        array($this, 'validate'),
      ),
    );
    return array('value' => $element);
  }

  /**
   * Validate the project text field.
   */
  public function validate($element, FormStateInterface $form_state) {
    $value = $element['#value'];
    if (strlen($value) == 0) {
      $form_state->setValueForElement($element, '');
      return;
    }
    if (intval($value) == 0) {
      $form_state->setError($element, t("Itch project number must be an integer"));
    }
  }

}
